# -*- coding: utf-8 -*-
# Generated by Django 1.10.5 on 2017-01-05 22:12
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('epic', '0004_auto_20150918_2111'),
    ]

    operations = [
        migrations.AlterField(
            model_name='datasheet',
            name='ds_file',
            field=models.FileField(upload_to=b'epic/datasheets', verbose_name=b'Datasheet File'),
        ),
    ]



# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import models, migrations
from decimal import Decimal
import epic.models
import django.core.validators


class Migration(migrations.Migration):

    dependencies = [
        ('epic', '0003_auto_20150915_1436'),
    ]

    operations = [
        migrations.AddField(
            model_name='datasheet',
            name='md5sum',
            field=models.CharField(null=True, max_length=36),
        ),
    ]
